@@ -18,4 +18,4 @@ class Card(EntityType):
                       description=_("an abstract for this card"))
     content  = RichString(fulltextindexed=True, internationalizable=True,
                           default_format='text/rest')
-    wikiid = String(maxsize=64, indexed=True)
+    wikiid = String(maxsize=64, unique=True)
